interceptor

package
v0.0.0-...-90d9442 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

const (
	FeatureFlagShowMavenBuildScope = "internal_snyk_show_maven_scope_enabled"
	FeatureFlagShowNpmBuildScope   = "internal_snyk_show_npm_scope_enabled"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Interceptor

type Interceptor interface {
	GetHandler() goproxy.FuncReqHandler
	GetCondition() goproxy.ReqCondition
}

Interceptor is an interface that defines self-registering MITM-style handlers for interacting with requests send to the go proxy from the legacy CLI. Add a new interceptor by implementing the Interceptor interface and adding it to the GetRegisteredInterceptors function.

func NewLegacyFeatureFlagInterceptor

func NewLegacyFeatureFlagInterceptor(invocationCtx workflow.InvocationContext) Interceptor

func NewNetworkInjector

func NewNetworkInjector(invocationCtx workflow.InvocationContext) Interceptor

func NewV1AnalyticsInterceptor

func NewV1AnalyticsInterceptor(invocationCtx workflow.InvocationContext) Interceptor

Jump to